#! /bin/bash

walltime=00:30:00
queue=lustre_scaling
account=HACC_aesp_CNDA

outName=tmp.gio
seed=3

baseName=base.sh

if [ $# -lt 5 ]
then
    echo "USAGE: $0 <exe> <nodes> <rpn> <file_count> <file_size_GB>"
    exit
fi
exe=$(realpath $1)
nodes=$2
rpn=$3
file_count=$4
file_size_GB=$5

if [ $rpn -gt 16 ]
then
    echo "ERROR: rpn = ${rpn} > 16 not supported"
    exit -1
fi

ranks=$(( $nodes * $rpn ))
if [ $file_count -gt $ranks ]
then
    file_count=$ranks
fi

prefix=$(dirname $(realpath ${BASH_SOURCE[0]}))
cd ${prefix}

#
nameBase="n${nodes}_rpn${rpn}_fc${file_count}_fs${file_size_GB}GB"
scriptName=test_${nameBase}.pbs.sh

# bash
echo "#! /bin/bash" > ${scriptName}
echo "" >> ${scriptName}

# PBS
echo "#PBS -l select=${nodes}" >> ${scriptName}
echo "#PBS -l walltime=${walltime}" >> ${scriptName}
echo "#PBS -q ${queue}" >> ${scriptName}
echo "#PBS -A ${account}" >> ${scriptName}
echo "#PBS -l place=scatter" >> ${scriptName}
echo "#PBS -l daos=default" >> ${scriptName} 
echo "#PBS -N ${nameBase}" >> ${scriptName}
#PBS -k doe
echo "" >> ${scriptName}

#
echo "outName=${outName}" >> ${scriptName}
echo "seed=${seed}" >> ${scriptName}
echo "" >> ${scriptName}

# variables from cmd line
echo "exe=${exe}" >> ${scriptName}
echo "nodes=${nodes}" >> ${scriptName}
echo "rpn=${rpn}" >> ${scriptName}
echo "file_count=${file_count}" >> ${scriptName}
echo "file_size_GB=${file_size_GB}" >> ${scriptName}
echo "" >> ${scriptName}

# 
echo "nameBase=${nameBase}" >> ${scriptName}
echo "ranks=${ranks}" >> ${scriptName}
echo "" >> ${scriptName}

# rest of script
cat ${baseName} >> ${scriptName}

# chmod
chmod a+x ${scriptName}
