#! /bin/bash

walltime=00:30:00
queue=lustre_scaling
account=Aurora_deployment

outName=tmp.gio
seed=3

baseName=base.sh

if [ $# -lt 8 ]
then
    echo "USAGE: $0 <exe> <darshan_so> <nodes> <rpn> <stripe_count> <stripe_size_MB> <file_count> <file_size_GB>"
    exit
fi
exe=$(realpath $1)
darshan_so=$(realpath $2)
nodes=$3
rpn=$4
stripe_count=$5
stripe_size_MB=$6
file_count=$7
file_size_GB=$8

if [ $rpn -gt 16 ]
then
    echo "ERROR: rpn = ${rpn} > 16 not supported"
    exit -1
fi

ranks=$(( $nodes * $rpn ))
if [ $file_count -gt $ranks ]
then
    file_count=$ranks
fi

prefix=$(dirname $(realpath ${BASH_SOURCE[0]}))
cd ${prefix}

# figure out new dir name
dirBase="n${nodes}_rpn${rpn}_sc${stripe_count}_ss${stripe_size_MB}MB_fc${file_count}_fs${file_size_GB}GB"

scriptName=test_${dirBase}.pbs.sh

# bash
echo "#! /bin/bash" > ${scriptName}
echo "" >> ${scriptName}

# PBS
echo "#PBS -l select=${nodes}" >> ${scriptName}
echo "#PBS -l walltime=${walltime}" >> ${scriptName}
echo "#PBS -q ${queue}" >> ${scriptName}
echo "#PBS -A ${account}" >> ${scriptName}
echo "#PBS -l place=scatter" >> ${scriptName}
echo "#PBS -N ${dirBase}" >> ${scriptName}
#PBS -k doe
echo "" >> ${scriptName}

#
echo "outName=${outName}" >> ${scriptName}
echo "seed=${seed}" >> ${scriptName}
echo "" >> ${scriptName}

# variables from cmd line
echo "exe=${exe}" >> ${scriptName}
echo "darshan_so=${darshan_so}" >> ${scriptName}
echo "nodes=${nodes}" >> ${scriptName}
echo "rpn=${rpn}" >> ${scriptName}
echo "stripe_count=${stripe_count}" >> ${scriptName}
echo "stripe_size_MB=${stripe_size_MB}" >> ${scriptName}
echo "file_count=${file_count}" >> ${scriptName}
echo "file_size_GB=${file_size_GB}" >> ${scriptName}
echo "" >> ${scriptName}

# 
echo "ranks=${ranks}" >> ${scriptName}
echo "dirBase=${dirBase}"  >> ${scriptName}
echo "cd ${prefix}" >> ${scriptName}
echo "" >> ${scriptName}

# rest of script
cat ${baseName} >> ${scriptName}

# chmod
chmod a+x ${scriptName}
