#!/bin/bash

#PBS -l select=1
#PBS -l place=scatter
#PBS -l walltime=01:00:00
#PBS -A Aurora_deployment
##PBS -A HACC_aesp_CNDA
#PBS -q lustre_scaling
#PBS -N run_w0wa_00001
#PBS -l daos=default

DAOS_POOL_NAME=HACC_aesp_CNDA
DAOS_CONT_NAME=hacc_posix
TEST_NAME=test_hacc_00001

export TZ='/usr/share/zoneinfo/US/Central'

cd $PBS_O_WORKDIR

source bashrc.aurora.kokkos_sycl_thirdparty

#export OMP_PROC_BIND=spread

export OMP_PLACES=threads 
export OMP_NUM_THREADS=8

export GENERICIO_RANK_PARTITIONS=1
export GENERICIO_PARTITIONS_USE_NAME=0

#unset OMP_PLACES

#export KOKKOS_PROFILE_LIBRARY="/lus/gila/projects/HACC_aesp_CNDA/nfrontiere/ArborX_Test/run_testing_summit/kp_ecp_kpp3.so"

NNODES=`wc -l < $PBS_NODEFILE`

NRANKS=12          # Number of MPI ranks per node

NDEPTH=8          # Number of hardware threads per rank, spacing between MPI ranks on a node

NTHREADS=$OMP_NUM_THREADS # Number of OMP threads per rank, given to OMP_NUM_THREADS

NTOTRANKS=$(( NNODES * NRANKS ))

CPU_BINDING=list:4-11:12-19:20-27:28-35:36-43:44-51:56-63:64-71:72-79:80-87:88-95:96-103

echo Working directory is $PBS_O_WORKDIR
echo Jobid: $PBS_JOBID
echo Running on host `hostname`
echo "NUM_NODES=${NNODES}  TOTAL_RANKS=${NTOTRANKS}  RANKS_PER_NODE=${NRANKS}  THREADS_PER_RANK=${OMP_NUM_THREADS}"
echo "OMP_PROC_BIND=$OMP_PROC_BIND OMP_PLACES=$OMP_PLACES"

module use /soft/modulefiles
module load daos/base

daos version
ps -f -u daos_agent | cat
env | grep DAOS

#
export FI_CXI_DEFAULT_CQ_SIZE=1048576

# choose one of these
#export MY_PRELOAD=/usr/lib64/libioil.so
export MY_PRELOAD=${DAOS_PRELOAD}

# will need this for mpiio but not for posix
#export ROMIO_FSTYPE_FORCE="daos:"

clean-dfuse.sh ${DAOS_POOL_NAME}:${DAOS_CONT_NAME}
launch-dfuse.sh ${DAOS_POOL_NAME}:${DAOS_CONT_NAME}

workdir=/tmp/${DAOS_POOL_NAME}/${DAOS_CONT_NAME}/${TEST_NAME}/${PBS_JOBID_SHORT}
mkdir -p ${workdir}
mkdir ${workdir}/params
cp params/* ${workdir}/params
mkdir ${workdir}/output
mkdir ${workdir}/analysis

prefix=/tmp/${TEST_NAME}
BINDIR=$( realpath . )
WCOLL=${PBS_NODEFILE} pdsh ${BINDIR}/symlink.sh ${workdir} ${prefix}

cp ${PBS_NODEFILE} ${prefix}/nodefile.txt
env > ${prefix}/env.txt

mpiexec --env LD_PRELOAD=${MY_PRELOAD} -n ${NTOTRANKS} -ppn ${NRANKS} --cpu-bind=${CPU_BINDING} --no-vni --envall ./gpu_tile_compact.sh ./hacc_p3m -n ${prefix}/params/indat.params 1> ${prefix}/hacc.stdout.txt 2> ${prefix}/hacc.stderr.txt

clean-dfuse.sh ${DAOS_POOL_NAME}:${DAOS_CONT_NAME}
